/*
* Copyright (c) 2003, University of Maryland 
* Copyright (c) 2003, Center for Satellite and Hybrid Communication Networks 
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without 
* modification, are permitted provided that the following conditions 
* are met:
*
*   * Redistributions of source code must retain the above copyright notice, 
*     this list of conditions,the authors and the following disclaimer.
*   * Redistributions in binary form must reproduce the above copyright notice,
*     this list of conditions,the authors and the following disclaimer in
*     the documentation and/or other materials provided with the distribution.
*   * Neither the name of the University of Maryland/Center for Satellite
*     and Hybrid Communication Networks nor the names of its 
*     contributors may be used to endorse or promote products derived from 
*     this software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
* ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
* LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
* POSSIBILITY OF SUCH DAMAGE.
*
*/

/* Authors: 
*     Jonathan Polley (jpolley@isr.umd.edu),
*     Dionysus Blazakis (dblaze@isr.umd.edu),
*     Jonathan McGee (mcgee@isr.umd.edu),
*     Daniel Rusk (ruskd@isr.umd.edu),
*     Manish Karir (karir@isr.umd.edu)
*/

#include <stdlib.h>
#include <stdio.h>

#include "radio.h"

#define NNODES 2
radio_air *nodes[NNODES];

#define F_BASE  9.16E8
#define F_TRUE  9.16E8-17
#define F_FALSE 9.16E8+17

s_r(double freq){
    int bit;
    double strength;
    
    air_transmit(nodes[0], freq);
    if(air_receive(nodes[1], &bit, &strength)){
        printf("Received bit %d at strength %e.\n", bit, strength);
    }else{
        printf("Didn't receive bit %d at strength %e.\n", bit, strength);
    }
}

int main(int argc, char *argv[]){
    int i, bit;
    double frequency, strength;

    for(i=0; i<NNODES; i++){
        nodes[i] = air_create_device();
        air_set_position(nodes[i], i, i, i);
    }

    /* node 0 transmits */
    /* 1 miliwatt, 916 MHz */
    air_transmit_power(nodes[0], 1E-7);
    air_transmit(nodes[0], F_TRUE);

    /* node 1 receives */
    air_receive_tuner(nodes[1], F_BASE, 50, 1E-12);
    if(air_receive_sense(nodes[1], &frequency, &strength)){
        printf("Sensed frequency %e with strength %e.\n", frequency, strength);
    }else{
        printf("Sensed no reasonable frequency.  frequency %e with strength %e.\n", frequency, strength);
    }
    air_receive_frequencies(nodes[1], F_FALSE, F_TRUE, 2.0/3.0);

    /* send some data */
    s_r(F_FALSE);
    s_r(F_TRUE);
    s_r(F_FALSE);
    s_r(F_FALSE);
    s_r(F_TRUE);
    s_r(F_TRUE);
    s_r(F_TRUE);
    s_r(F_FALSE);
    s_r(F_TRUE);
    s_r(F_FALSE);
    s_r(F_TRUE);

    air_destroy_device(nodes[0]);
    air_destroy_device(nodes[1]);
}
